#ifndef _Track_H
#define _Track_H

/** @class Track Track 
 *
 *  Define a Track a the combination of 2 straight lines
 *
 *  @author M.Needham
 *  @date   31/05/2004
 */

#include "Line.h"

class Track{

public:

  Track(const Line& xLine, const Line& yLine);

  virtual ~Track(){}

  double x(const double z) const;

  double y(const double z) const;

  double tx() const;

  double ty() const;

  void   setEventnum(int eventnum);
  void   setTracknum(int tracknum);
  void   setPVnum(int tracknum);
  void   setOrigin(double origin[]);
  void   setZclos(double zclos);
  void   setDirection(bool forward);
  void   setSide(bool side);


  int    getEventnum() const;
  int    getTracknum() const;
  int    getPVnum() const;
  void   getOrigin(double origin[]);
  double getZclos() const;
  bool   getDirection();
  bool   getSide();

private:

  Line m_xLine;
  Line m_yLine;

  int    m_eventnum;
  int    m_PVnum;
  int    m_tracknum;
  double m_origin[3];
  double m_zclos;
  bool   m_forward;
  bool   m_side;
}; 


#include <vector>
typedef std::vector<Track*> Tracks;

inline Track::Track(const Line& xLine, const Line& yLine):
m_xLine(xLine),
m_yLine(yLine)
{
  m_tracknum = -1;
  m_eventnum = -1;
  m_PVnum    = -1;
  for (int i=0;i<3;++i) m_origin[i] = 0.;
  m_forward  = true;
  m_zclos = 0.;

  // constructer
}

inline double Track::x(const double z) const{
  return m_xLine.value(z);
}

inline double Track::y(const double z) const{
  return m_yLine.value(z);
}

inline double Track::tx() const{
  return m_xLine.m();
}

inline double Track::ty() const{
  return m_yLine.m();
}

inline void Track::setTracknum(int tracknum) {
  m_tracknum = tracknum ;
}

inline void Track::setEventnum(int eventnum) {
  m_eventnum = eventnum ;
}

inline void Track::setPVnum(int PVnum) {
  m_PVnum = PVnum ;
}

inline void Track::setZclos(double zclos) {
  m_zclos = zclos ;
}

inline void Track::setOrigin(double origin[]) {

  for (int i = 0; i<3; ++i)
    m_origin[i] = origin[i] ;
}

inline void Track::setDirection(bool forward) {
  m_forward = forward ;
}

inline void Track::setSide(bool side) {
  m_side = side ;
}

inline int Track::getTracknum() const{
  return m_tracknum;
}

inline int Track::getEventnum() const{
  return m_eventnum;
}

inline int Track::getPVnum() const{
  return m_PVnum;
}

inline double Track::getZclos() const{
  return m_zclos;
}

inline void Track::getOrigin(double origin[]) {

  for (int i = 0; i<3; ++i)
    origin[i] = m_origin[i] ;
}

inline bool Track::getDirection() {
  return m_forward;
}

inline bool Track::getSide() {
  return m_side;
}

#endif // _Track_H
